import React from 'react';
import { StyleSheet, Text, TouchableOpacity, View } from 'react-native';
import { Constants } from '../utils';
import ClearIcon from './clearIcon';

/**
 * Renders a header component with a title and a "Clear All" (deletes all the notifications till date) action.
 *
 * @component
 * @example
 * <Header
 *   title="Notification Center"
 *   styles={customStyles}
 *   onClearAllNotifications={() => console.log('All notifications cleared')}
 *   clearAllDisabled={false}
 * />
 *
 * @param {Object} props - The properties passed to the Header component.
 * @param {string} props.title - The title to be displayed in the header.
 * @param {Object} props.styles - Custom styles to apply to the header component.
 * @param {Function} props.onClearAllNotifications - A callback function that is called when the "Clear All" action is triggered.
 * @param {boolean} props.clearAllDisabled - Disables the clear all button.
 */

const Header = props => {
  const {
    title = '',
    styles,
    onPressClearAll,
    clearAllDisabled = false,
    hideClearAll
  } = props;
  return /*#__PURE__*/React.createElement(View, {
    style: [style.headerContainer, styles.headerContainer]
  }, /*#__PURE__*/React.createElement(Text, {
    numberOfLines: 1,
    style: [style.headerTitle, styles.headerTitle]
  }, title), !hideClearAll && /*#__PURE__*/React.createElement(View, {
    style: style.clearIconContainer
  }, /*#__PURE__*/React.createElement(ClearIcon, {
    styles: styles
  }), /*#__PURE__*/React.createElement(TouchableOpacity, {
    disabled: clearAllDisabled,
    onPress: onPressClearAll
  }, /*#__PURE__*/React.createElement(Text, {
    style: styles.headerAction
  }, Constants.CLEAR_ALL_LABEL))));
};
const style = StyleSheet.create({
  headerContainer: {
    width: '100%',
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center',
    paddingVertical: 10,
    paddingHorizontal: 15
  },
  clearIconContainer: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'center'
  },
  headerTitle: {
    width: '70%'
  }
});
export default Header;
//# sourceMappingURL=header.js.map