import { defaultStyles, eventTypes, levelLogFns, LogLevel, ThemeMode } from './constants';
import { DefaultTheme } from './index';
export const isNonEmptyArray = arr => Boolean(arr && typeof arr === 'object' && arr instanceof Array && arr.length > 0);
export const updateNotifications = (eventData, notifications) => {
  let updatedNotifications = [];
  switch (eventData.action) {
    case eventTypes.MARK_ITEM_AS_READ:
      updatedNotifications = notifications.map(item => item.id === eventData.id ? {
        ...item,
        isRead: true
      } : item);
      break;
    case eventTypes.MARK_ALL_AS_READ:
      updatedNotifications = notifications.map(item => ({
        ...item,
        isRead: true
      }));
      break;
    case eventTypes.DELETE_ITEM:
      updatedNotifications = notifications.filter(item => item.id != eventData.id);
      break;
    case eventTypes.DELETE_ALL_ITEM:
      updatedNotifications = [];
      break;
    case eventTypes.NEW_NOTIFICATIONS:
      {
        const newNotifications = eventData?.newNotifications || [];
        updatedNotifications = [...newNotifications, ...notifications];
        break;
      }
    case eventTypes.RESET_NOTIFICATIONS:
      {
        updatedNotifications = [];
        break;
      }
    default:
      break;
  }
  return updatedNotifications;
};
export const generateElapsedTimeText = timeString => {
  const currentTime = new Date().getTime();
  const targetTime = new Date(timeString).getTime();
  const millisecondsDiff = currentTime - targetTime;
  const seconds = Math.floor(millisecondsDiff / 1000);
  const minutes = Math.floor(seconds / 60);
  const hours = Math.floor(minutes / 60);
  const days = Math.floor(hours / 24);
  const years = Math.floor(days / 365);
  if (millisecondsDiff < 60000) return 'Just now';else if (minutes < 60) return minutes === 1 ? '1 minute ago' : `${minutes} minutes ago`;else if (hours < 24) return hours === 1 ? '1 hour ago' : `${hours} hours ago`;else if (days < 365) return days === 1 ? '1 day ago' : `${days} days ago`;else return years === 1 ? '1 year ago' : `${years} years ago`;
};
export const logger = {
  log: async (level, message) => {
    const timestamp = new Date().toISOString();
    const levelString = LogLevel[level]?.toUpperCase();
    const levelLogFn = levelLogFns[level];
    levelLogFn(`[${timestamp}] [${levelString}] ${message}`);
  },
  error: function (error) {
    this.log(LogLevel.ERROR, error);
  },
  info: function (message) {
    this.log(LogLevel.INFO, message);
  }
};
export const applyTheme = (theme = {}, customStyles = {}, mode = ThemeMode.LIGHT) => ({
  container: {
    backgroundColor: theme.windowContainer?.background || theme.colors?.neutralColor || DefaultTheme[mode].windowContainer.background,
    width: customStyles.window?.width || defaultStyles.window?.width,
    height: customStyles.window?.height || defaultStyles.window?.height
  },
  contentContainer: {
    backgroundColor: theme.windowContainer?.background || theme.colors?.neutralColor || DefaultTheme[mode].windowContainer.background,
    padding: customStyles.windowContainer?.padding || defaultStyles.windowContainer?.padding
  },
  headerContainer: {
    backgroundColor: theme.windowHeader?.background || theme.colors?.neutralColor || DefaultTheme[mode].windowHeader.background,
    borderBottomColor: theme.windowHeader?.borderColor || theme.colors?.borderColor || DefaultTheme[mode].windowHeader?.borderColor,
    borderBottomWidth: customStyles.windowHeader?.borderWidth || defaultStyles.windowHeader?.borderWidth,
    height: customStyles.windowHeader?.height || defaultStyles.windowHeader?.height
  },
  headerTitle: {
    color: theme.windowHeader?.titleColor || theme.colors?.textColor || DefaultTheme[mode].windowHeader.titleColor,
    fontSize: customStyles.windowHeader?.titleSize || defaultStyles.windowHeader.titleSize,
    fontWeight: customStyles.windowHeader?.titleFontWeight || defaultStyles.windowHeader.titleFontWeight,
    paddingLeft: customStyles.windowHeader?.titlePadding || defaultStyles.windowHeader.titlePadding
  },
  headerAction: {
    color: theme.windowHeader?.headerActionColor || theme.colors?.clearAllIcon || DefaultTheme[mode].windowHeader.headerActionColor
  },
  clearIcon: {
    backgroundColor: theme.windowHeader?.headerActionColor || theme.colors?.clearAllIcon || DefaultTheme[mode].windowHeader.headerActionColor,
    height: (customStyles.clearAllIcon?.size || defaultStyles.clearAllIcon.size) * 0.1,
    borderRadius: (customStyles.clearAllIcon?.size || defaultStyles.clearAllIcon.size) * 0.12,
    marginTop: (customStyles.clearAllIcon?.size || defaultStyles.clearAllIcon.size) * 0.1,
    marginBottom: (customStyles.clearAllIcon?.size || defaultStyles.clearAllIcon.size) * 0.05,
    marginRight: (customStyles.clearAllIcon?.size || defaultStyles.clearAllIcon.size) * 0.5
  },
  clearIconContainer: {
    width: customStyles.clearAllIcon?.size || defaultStyles.clearAllIcon.size,
    height: customStyles.clearAllIcon?.size || defaultStyles.clearAllIcon.size,
    marginRight: (customStyles.clearAllIcon?.size || defaultStyles.clearAllIcon.size) * 0.2
  },
  timerIcon: {
    borderColor: theme.colors?.timerIcon || DefaultTheme[mode].colors.timerIcon,
    width: customStyles.dateIcon?.size || defaultStyles.dateIcon.size,
    height: customStyles.dateIcon?.size || defaultStyles.dateIcon.size,
    borderRadius: (customStyles.dateIcon?.size || defaultStyles.dateIcon.size) / 2,
    borderWidth: (customStyles.dateIcon?.size || defaultStyles.dateIcon.size) * 0.1,
    padding: (customStyles.dateIcon?.size || defaultStyles.dateIcon.size) * 0.1
  },
  timerIconLine: {
    backgroundColor: theme.colors?.timerIcon || DefaultTheme[mode].colors.timerIcon,
    height: (customStyles.dateIcon?.size || defaultStyles.dateIcon.size) * 0.36,
    width: (customStyles.dateIcon?.size || defaultStyles.dateIcon.size) * 0.1
  },
  timerIconLine2: {
    backgroundColor: theme.colors?.timerIcon || DefaultTheme[mode].colors.timerIcon,
    height: (customStyles.dateIcon?.size || defaultStyles.dateIcon.size) * 0.28,
    width: (customStyles.dateIcon?.size || defaultStyles.dateIcon.size) * 0.1,
    marginLeft: (customStyles.dateIcon?.size || defaultStyles.dateIcon.size) * 0.22,
    marginTop: -(customStyles.dateIcon?.size || defaultStyles.dateIcon.size) * 0.1
  },
  cardContainer: {
    padding: customStyles.notificationCard?.padding || defaultStyles.notificationCard.padding
  },
  cardWrapper: {
    backgroundColor: theme.notificationCard?.background || DefaultTheme[mode].notificationCard.background,
    borderBottomColor: theme.notificationCard?.borderColor || theme.colors?.borderColor || DefaultTheme[mode].notificationCard.borderColor,
    borderBottomWidth: customStyles.notificationCard?.borderWidth || defaultStyles.notificationCard.borderWidth
  },
  activeCardMarker: {
    backgroundColor: theme.colors?.primaryColor || DefaultTheme[mode].colors?.primaryColor
  },
  cardIconRound: {
    width: customStyles.notificationCard?.avatarSize || defaultStyles.notificationCard.avatarSize,
    height: customStyles.notificationCard?.avatarSize || defaultStyles.notificationCard.avatarSize,
    borderRadius: (customStyles.notificationCard?.avatarSize || defaultStyles.notificationCard.avatarSize) / 2
  },
  closeIcon: {
    backgroundColor: theme.colors?.deleteIcon || DefaultTheme[mode].colors.deleteIcon,
    height: (customStyles.deleteIcon?.size || defaultStyles.deleteIcon.size) * 0.14
  },
  closeButton: {
    width: customStyles.deleteIcon?.size || defaultStyles.deleteIcon.size,
    height: customStyles.deleteIcon?.size || defaultStyles.deleteIcon.size
  },
  cardTitle: {
    color: theme.notificationCard?.titleColor || theme.colors?.textColor || DefaultTheme[mode].notificationCard.titleColor,
    fontSize: customStyles.notificationCard?.titleSize || defaultStyles.notificationCard.titleSize,
    fontWeight: customStyles.notificationCard?.titleFontWeight || defaultStyles.notificationCard.titleFontWeight
  },
  cardDescription: {
    color: theme.notificationCard?.descriptionColor || theme.colors?.textColor || DefaultTheme[mode].notificationCard.descriptionColor,
    fontSize: customStyles.notificationCard?.descriptionSize || defaultStyles.notificationCard.descriptionSize
  },
  dateStyle: {
    color: theme.notificationCard?.dateColor || theme.colors?.dateColor || DefaultTheme[mode].notificationCard.dateColor,
    fontSize: customStyles.notificationCard?.dateSize || defaultStyles.notificationCard.dateSize
  },
  emptyText: {
    color: theme.colors?.textColor || DefaultTheme[mode].colors.textColor
  },
  errorText: {
    color: theme.colors?.textColor || DefaultTheme[mode].colors.textColor
  },
  errorButton: {
    backgroundColor: theme.colors?.primaryColor || DefaultTheme[mode].colors.primaryColor
  },
  errorButtonText: {
    color: theme.colors?.textColor || DefaultTheme[mode].colors.textColor
  },
  skeltonLoaderColor: {
    backgroundColor: theme.colors?.textColor || DefaultTheme[mode].colors.textColor
  },
  highlighted: {
    backgroundColor: theme.colors?.highlightedCardColor || DefaultTheme[mode].colors.highlightedCardColor
  }
});
//# sourceMappingURL=commonUtils.js.map